==> prism-react-renderer-0.0.1.tgz: package/es/components/Highlight.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React, { Component } from "react";
import normalizeTokens from "../utils/normalizeTokens";
import themeToDict from "../utils/themeToDict";

var Highlight =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(Highlight, _Component);

  function Highlight(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.themeDict = void 0;

    _this.getLineProps = function (_ref) {
      var key = _ref.key,
          className = _ref.className,
          style = _ref.style,
          line = _ref.line;
      var output = {
        className: "token-line",
        style: undefined,
        key: undefined
      };

      if (_this.themeDict !== undefined) {
        output.style = _this.themeDict.plain;
      }

      if (style !== undefined) {
        output.style = output.style !== undefined ? _extends({}, style, output.style) : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += " " + className;
      return output;
    };

    _this.getTokenProps = function (_ref2) {
      var key = _ref2.key,
          className = _ref2.className,
          style = _ref2.style,
          token = _ref2.token;
      var output = {
        className: "token " + token.type,
        children: token.content,
        style: undefined,
        key: undefined
      };

      if (_this.themeDict !== undefined && token.type !== "plain") {
        output.style = _this.themeDict[token.type] || undefined;
      }

      if (style !== undefined) {
        output.style = output.style !== undefined ? _extends({}, style, output.style) : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += " " + className;
      return output;
    };

    if (props.theme) {
      _this.themeDict = themeToDict(props.theme, props.language);
    }

    return _this;
  }

  var _proto = Highlight.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        Prism = _this$props.Prism,
        language = _this$props.language,
        code = _this$props.code,
        children = _this$props.children;
    var grammar = Prism.languages[language];
    var mixedTokens = Prism.tokenize(code, grammar, language);
    var tokens = normalizeTokens(mixedTokens);
    return children({
      tokens: tokens,
      className: "prism-code language-" + language,
      style: this.themeDict ? this.themeDict.root : {},
      getLineProps: this.getLineProps,
      getTokenProps: this.getTokenProps
    });
  };

  return Highlight;
}(Component);

export default Highlight;

==> prism-react-renderer-0.0.2.tgz: package/es/components/Highlight.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React, { Component } from "react";
import normalizeTokens from "../utils/normalizeTokens";
import themeToDict from "../utils/themeToDict";

var Highlight =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(Highlight, _Component);

  function Highlight(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.themeDict = void 0;

    _this.getLineProps = function (_ref) {
      var key = _ref.key,
          className = _ref.className,
          style = _ref.style,
          line = _ref.line;
      var output = {
        className: "token-line",
        style: undefined,
        key: undefined
      };

      if (_this.themeDict !== undefined) {
        output.style = _this.themeDict.plain;
      }

      if (style !== undefined) {
        output.style = output.style !== undefined ? _extends({}, output.style, style) : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += " " + className;
      return output;
    };

    _this.getStyleForTypes = function (types) {
      var typesSize = types.length;

      if (_this.themeDict === undefined) {
        return undefined;
      } else if (typesSize === 1 && types[0] === 'plain') {
        return undefined;
      } else if (typesSize === 1) {
        return _this.themeDict[types[0]];
      } // $FlowFixMe


      return Object.assign.apply(Object, [{}].concat(types.map(function (type) {
        return _this.themeDict[type];
      })));
    };

    _this.getTokenProps = function (_ref2) {
      var key = _ref2.key,
          className = _ref2.className,
          style = _ref2.style,
          token = _ref2.token;
      var output = {
        className: "token " + token.types.join(' '),
        children: token.content,
        style: _this.getStyleForTypes(token.types),
        key: undefined
      };

      if (style !== undefined) {
        output.style = output.style !== undefined ? _extends({}, output.style, style) : style;
      }

      if (key !== undefined) output.key = key;
      if (className) output.className += " " + className;
      return output;
    };

    if (props.theme) {
      _this.themeDict = themeToDict(props.theme, props.language);
    }

    return _this;
  }

  var _proto = Highlight.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        Prism = _this$props.Prism,
        language = _this$props.language,
        code = _this$props.code,
        children = _this$props.children;
    var grammar = Prism.languages[language];
    var mixedTokens = Prism.tokenize(code, grammar, language);
    var tokens = normalizeTokens(mixedTokens);
    return children({
      tokens: tokens,
      className: "prism-code language-" + language,
      style: this.themeDict ? this.themeDict.root : {},
      getLineProps: this.getLineProps,
      getTokenProps: this.getTokenProps
    });
  };

  return Highlight;
}(Component);

export default Highlight;
